@@ -1,7 +1,8 @@
 from dataclasses import is_dataclass
 from abc import ABCMeta, abstractmethod
 from typing import List, Any, Callable, Dict, Union
-from collections import MutableSequence, Sequence, defaultdict
+from collections import defaultdict
+from collections.abc import MutableSequence, Sequence
 from itertools import chain
 from operator import methodcaller, attrgetter
 
@@ -20,6 +21,7 @@ class Indicator(Sequence):
         self.output_values: ListAny = []
         self.managed_sequences: List[ManagedSequenceType] = []
         self.sub_indicators: List[Indicator] = []
+        self.output_listeners: List[Indicator] = []
 
     @abstractmethod
     def _calculate_new_value(self) -> Any:
@@ -40,24 +42,40 @@ class Indicator(Sequence):
     def add_managed_sequence(self, lst: ManagedSequenceType) -> None:
         self.managed_sequences.append(lst)
 
-    def initialize(self, input_values: ListAny) -> None:
+    def initialize(self, input_values: ListAny = None, input_indicator: 'Indicator' = None) -> None:
+        if input_values is not None and input_indicator is not None:
+            raise Exception('Indicator cannot be initialized with both input_values and input_indicator!')
+
         self.remove_all()
 
         if input_values is not None:
             for value in input_values:
                 self.add_input_value(value)
 
+        if input_indicator is not None:
+            for value in input_indicator:
+                self.add_input_value(value)
+
+            input_indicator.add_output_listener(self)
+
     def add_input_value(self, value: Any) -> None:
         for sub_indicator in self.sub_indicators:
             sub_indicator.add_input_value(value)
 
-        if self.value_extractor is not None:
-            value = self.value_extractor(value)
-        self.input_values.append(value)
+        if not isinstance(value, list):
+            value = [value]
 
-        new_value = self._calculate_new_value()
-        if new_value is not None:
-            self.output_values.append(new_value)
+        for input_value in value:
+            if self.value_extractor is not None:
+                input_value = self.value_extractor(input_value)
+            self.input_values.append(input_value)
+
+            new_value = self._calculate_new_value()
+            if new_value is not None:
+                self.output_values.append(new_value)
+
+                for listener in self.output_listeners:
+                    listener.add_input_value(new_value)
 
     def update_input_value(self, value: Any) -> None:
         self.remove_input_value()
@@ -67,7 +85,8 @@ class Indicator(Sequence):
         for sub_indicator in self.sub_indicators:
             sub_indicator.remove_input_value()
 
-        self.input_values.pop(-1)
+        if len(self.input_values) > 0:
+            self.input_values.pop(-1)
 
         self._remove_output_value()
 
@@ -80,6 +99,9 @@ class Indicator(Sequence):
 
         self._remove_input_value_custom()
 
+        for listener in self.output_listeners:
+            listener.remove_input_value()
+
     def _remove_output_value(self) -> None:
         if len(self.output_values) > 0:
             self.output_values.pop(-1)
@@ -102,9 +124,38 @@ class Indicator(Sequence):
 
         self._remove_all_custom()
 
+        for listener in self.output_listeners:
+            listener.remove_all()
+
     def _remove_all_custom(self) -> None:
         pass
 
+    def purge_oldest(self, size: int) -> None:
+        for sub_indicator in self.sub_indicators:
+            sub_indicator.purge_oldest(size)
+
+        if len(self.input_values) > 0:
+            self.input_values = self.input_values[size:]
+
+        self._purge_oldest_output_value(size)
+
+        for lst in self.managed_sequences:
+            if isinstance(lst, Indicator):
+                lst.purge_oldest(size)
+            else:
+                del lst[:size]
+
+        self._purge_oldest_custom(size)
+
+        for listener in self.output_listeners:
+            listener.purge_oldest(size)
+
+    def _purge_oldest_output_value(self, size: int) -> None:
+        self.output_values = self.output_values[size:]
+
+    def _purge_oldest_custom(self, size: int) -> None:
+        pass
+
     def set_input_values(self, input_values: ListAny, initialize: bool = True) -> None:
         if initialize:
             self.initialize(input_values)
@@ -127,4 +178,7 @@ class Indicator(Sequence):
                     result[key].extend([value])
                 return dict(result)
             else:
-                raise Exception("to_lists() method can be used only with indicators returning multiple values as their result.")
\ No newline at end of file
+                raise Exception("to_lists() method can be used only with indicators returning multiple values as their result.")
+
+    def add_output_listener(self, listener: 'Indicator') -> None:
+        self.output_listeners.append(listener)
\ No newline at end of file
