@@ -9,12 +9,12 @@ class SMMA(Indicator):
 
     Output: a list of floats
     """
-    def __init__(self, period: int, input_values: List[float] = None):
+    def __init__(self, period: int, input_values: List[float] = None, input_indicator: Indicator = None):
         super().__init__()
 
         self.period = period
 
-        self.initialize(input_values)
+        self.initialize(input_values, input_indicator)
 
     def _calculate_new_value(self) -> Any:
         if len(self.input_values) < self.period:
